@@ -20,7 +20,9 @@
 #include "gdk/gdk.h"
 #include "gdk/gdkwayland.h"
 
-int check_wayland() {
+int
+check_wayland()
+{
     if (GDK_IS_WAYLAND_DISPLAY(gdk_display_get_default())) {
         return 1;
     } else {
